# Abaqus Output Database

The Python ODB API commands are used to read and write data from an output database (.odb) file. The path to the Odb object can be via the session.odbs repository or via a variable. In this chapter the Access and Path statements refer to a variable called odb that represents an existing Odb object.

## Classes

### Odb

```{eval-rst}
.. autoclass:: abaqus.Odb.Odb.Odb
    :members:
    :show-inheritance:

    .. autoclasstoc::
```

### Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.Odb
        :recursive:
        :exclude: Odb

    .. placeholder for empty members
```
